@@ -29,8 +29,8 @@ tbl$another_chr <- tail(letters, 10)
 test_that("%in% handles dictionary type", {
   df <- tibble::tibble(x = factor(c("a", "b", "c")))
   compare_dplyr_binding(
-    .input %>%
-      filter(x %in% "a") %>%
+    .input |>
+      filter(x %in% "a") |>
       collect(),
     df
   )
@@ -38,103 +38,103 @@ test_that("%in% handles dictionary type", {
 
 test_that("if_else and ifelse", {
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(int > 5, 1, 0),
         y2 = dplyr::if_else(int > 6, 1, 0)
-      ) %>%
+      ) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(int > 5, int, 0L)
-      ) %>%
+      ) |>
       collect(),
     tbl
   )
 
   expect_error(
-    Table$create(tbl) %>%
+    Table$create(tbl) |>
       mutate(
         y = if_else(int > 5, 1, FALSE)
-      ) %>%
+      ) |>
       collect(),
     "NotImplemented: Function 'if_else' has no kernel matching input types"
   )
 
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(int > 5, 1, NA_real_)
-      ) %>%
+      ) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = ifelse(int > 5, 1, 0),
         y2 = base::ifelse(int > 6, 1, 0)
-      ) %>%
+      ) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(dbl > 5, TRUE, FALSE)
-      ) %>%
+      ) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(chr %in% letters[1:3], 1L, 3L)
-      ) %>%
+      ) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(int > 5, "one", "zero")
-      ) %>%
+      ) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(int > 5, chr, another_chr)
-      ) %>%
+      ) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(int > 5, "true", chr, missing = "MISSING")
-      ) %>%
+      ) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(int > 5, fct, factor("a"))
-      ) %>%
-      collect() %>%
+      ) |>
+      collect() |>
       # Arrow if_else() kernel does not preserve unused factor levels,
       # so reset the levels of all the factor columns to make the test pass
       # (ARROW-14649)
@@ -147,10 +147,10 @@ test_that("if_else and ifelse", {
 
   # detecting NA and NaN works just fine
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(is.na(dbl), chr, "false", missing = "MISSING")
-      ) %>%
+      ) |>
       collect(),
     example_data_for_sorting
   )
@@ -158,18 +158,18 @@ test_that("if_else and ifelse", {
   # However, currently comparisons with NaNs return false and not NaNs or NAs
   skip("ARROW-13364")
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         y = if_else(dbl > 5, chr, another_chr, missing = "MISSING")
-      ) %>%
+      ) |>
       collect(),
     example_data_for_sorting
   )
 
   skip("TODO: could? should? we support the autocasting in ifelse")
   compare_dplyr_binding(
-    .input %>%
-      mutate(y = ifelse(int > 5, 1, FALSE)) %>%
+    .input |>
+      mutate(y = ifelse(int > 5, 1, FALSE)) |>
       collect(),
     tbl
   )
@@ -177,28 +177,28 @@ test_that("if_else and ifelse", {
 
 test_that("case_when()", {
   compare_dplyr_binding(
-    .input %>%
-      transmute(cw = case_when(lgl ~ dbl, !false ~ dbl + dbl2)) %>%
+    .input |>
+      transmute(cw = case_when(lgl ~ dbl, !false ~ dbl + dbl2)) |>
       collect(),
     tbl
   )
   compare_dplyr_binding(
-    .input %>%
-      mutate(cw = case_when(int > 5 ~ 1, TRUE ~ 0)) %>%
+    .input |>
+      mutate(cw = case_when(int > 5 ~ 1, TRUE ~ 0)) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
-      mutate(cw = case_when(int > 5 ~ 1, .default = 0)) %>%
+    .input |>
+      mutate(cw = case_when(int > 5 ~ 1, .default = 0)) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
-      transmute(cw = case_when(chr %in% letters[1:3] ~ 1L) + 41L) %>%
+    .input |>
+      transmute(cw = case_when(chr %in% letters[1:3] ~ 1L) + 41L) |>
       collect(),
     tbl
   )
@@ -208,8 +208,8 @@ test_that("case_when()", {
   withr::with_options(list(arrow.debug = TRUE), {
     expect_output(
       compare_dplyr_binding(
-        .input %>%
-          transmute(cw = case_when(isIn(chr, letters[1:3]) ~ 1L) + 41L) %>%
+        .input |>
+          transmute(cw = case_when(isIn(chr, letters[1:3]) ~ 1L) + 41L) |>
           collect(),
         tbl
       ),
@@ -218,24 +218,30 @@ test_that("case_when()", {
   })
 
   compare_dplyr_binding(
-    .input %>%
-      filter(case_when(
-        dbl + int - 1.1 == dbl2 ~ TRUE,
-        NA ~ NA,
-        TRUE ~ FALSE
-      ) & !is.na(dbl2)) %>%
+    .input |>
+      filter(
+        case_when(
+          dbl + int - 1.1 == dbl2 ~ TRUE,
+          NA ~ NA,
+          TRUE ~ FALSE
+        ) &
+          !is.na(dbl2)
+      ) |>
       collect(),
     tbl
   )
 
   # with namespacing
   compare_dplyr_binding(
-    .input %>%
-      filter(dplyr::case_when(
-        dbl + int - 1.1 == dbl2 ~ TRUE,
-        NA ~ NA,
-        TRUE ~ FALSE
-      ) & !is.na(dbl2)) %>%
+    .input |>
+      filter(
+        dplyr::case_when(
+          dbl + int - 1.1 == dbl2 ~ TRUE,
+          NA ~ NA,
+          TRUE ~ FALSE
+        ) &
+          !is.na(dbl2)
+      ) |>
       collect(),
     tbl
   )
@@ -243,16 +249,18 @@ test_that("case_when()", {
   # dplyr::case_when() errors if values on right side of formulas do not have
   # exactly the same type, but the Arrow case_when kernel allows compatible types
   expect_equal(
-    tbl %>%
-      mutate(i64 = as.integer64(1e10)) %>%
-      Table$create() %>%
-      transmute(cw = case_when(
-        is.na(fct) ~ int,
-        is.na(chr) ~ dbl,
-        TRUE ~ i64
-      )) %>%
+    tbl |>
+      mutate(i64 = as.integer64(1e10)) |>
+      Table$create() |>
+      transmute(
+        cw = case_when(
+          is.na(fct) ~ int,
+          is.na(chr) ~ dbl,
+          TRUE ~ i64
+        )
+      ) |>
       collect(),
-    tbl %>%
+    tbl |>
       transmute(
         cw = ifelse(is.na(fct), int, ifelse(is.na(chr), dbl, 1e10))
       )
@@ -305,23 +313,23 @@ test_that("case_when()", {
   )
 
   compare_dplyr_binding(
-    .input %>%
-      transmute(cw = case_when(lgl ~ "abc")) %>%
+    .input |>
+      transmute(cw = case_when(lgl ~ "abc")) |>
       collect(),
     tbl
   )
   compare_dplyr_binding(
-    .input %>%
-      transmute(cw = case_when(lgl ~ verses, !false ~ paste(chr, chr))) %>%
+    .input |>
+      transmute(cw = case_when(lgl ~ verses, !false ~ paste(chr, chr))) |>
       collect(),
     tbl
   )
 
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         cw = case_when(!(!(!(lgl))) ~ factor(chr), TRUE ~ fct)
-      ) %>%
+      ) |>
       collect(),
     tbl,
     warning = TRUE
@@ -337,45 +345,45 @@ test_that("coalesce()", {
     z = c("a", "b", "c")
   )
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         cw = coalesce(w),
         cz = coalesce(z),
         cwx = coalesce(w, x),
         cwxy = coalesce(w, x, y),
         cwxyz = coalesce(w, x, y, z)
-      ) %>%
+      ) |>
       collect(),
     df
   )
 
   # with namespacing
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         cw = dplyr::coalesce(w),
         cz = dplyr::coalesce(z),
         cwx = dplyr::coalesce(w, x),
         cwxy = dplyr::coalesce(w, x, y),
         cwxyz = dplyr::coalesce(w, x, y, z)
-      ) %>%
+      ) |>
       collect(),
     df
   )
 
   # factor
-  df_fct <- df %>%
+  df_fct <- df |>
     transmute(across(everything(), ~ factor(.x, levels = c("a", "b", "c"))))
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         cw = coalesce(w),
         cz = coalesce(z),
         cwx = coalesce(w, x),
         cwxy = coalesce(w, x, y),
         cwxyz = coalesce(w, x, y, z)
-      ) %>%
-      collect() %>%
+      ) |>
+      collect() |>
       # Arrow coalesce() kernel does not preserve unused factor levels,
       # so reset the levels of all the factor columns to make the test pass
       # (ARROW-14649)
@@ -391,14 +399,14 @@ test_that("coalesce()", {
     z = 1:3
   )
   compare_dplyr_binding(
-    .input %>%
+    .input |>
       mutate(
         cw = coalesce(w),
         cz = coalesce(z),
         cwx = coalesce(w, x),
         cwxy = coalesce(w, x, y),
         cwxyz = coalesce(w, x, y, z)
-      ) %>%
+      ) |>
       collect(),
     df
   )
@@ -414,14 +422,14 @@ test_that("coalesce()", {
   # we can't use compare_dplyr_binding here as dplyr silently converts NaN to NA in coalesce()
   # see https://github.com/tidyverse/dplyr/issues/6833
   expect_identical(
-    arrow_table(df) %>%
+    arrow_table(df) |>
       mutate(
         cw = coalesce(w),
         cz = coalesce(z),
         cwx = coalesce(w, x),
         cwxy = coalesce(w, x, y),
         cwxyz = coalesce(w, x, y, z)
-      ) %>%
+      ) |>
       collect(),
     mutate(
       df,
@@ -436,34 +444,35 @@ test_that("coalesce()", {
   # NaNs stay NaN and are not converted to NA in the results
   # (testing this requires expect_identical())
   expect_identical(
-    df %>% Table$create() %>% mutate(cwx = coalesce(w, x)) %>% collect(),
-    df %>% mutate(cwx = c(NA, NaN, 3.3))
+    df |> Table$create() |> mutate(cwx = coalesce(w, x)) |> collect(),
+    df |> mutate(cwx = c(NA, NaN, 3.3))
   )
   expect_identical(
-    df %>% Table$create() %>% transmute(cw = coalesce(w)) %>% collect(),
-    df %>% transmute(cw = w)
+    df |> Table$create() |> transmute(cw = coalesce(w)) |> collect(),
+    df |> transmute(cw = w)
   )
   expect_identical(
-    df %>% Table$create() %>% transmute(cn = coalesce(NaN)) %>% collect(),
-    df %>% transmute(cn = NaN)
+    df |> Table$create() |> transmute(cn = coalesce(NaN)) |> collect(),
+    df |> transmute(cn = NaN)
   )
   # singles stay single
   expect_equal(
-    (df %>%
-      Table$create(schema = schema(
-        w = float32(),
-        x = float32(),
-        y = float32(),
-        z = float32()
-      )) %>%
-      transmute(c = coalesce(w, x, y, z)) %>%
-      compute()
-    )$schema[[1]]$type,
+    (df |>
+      Table$create(
+        schema = schema(
+          w = float32(),
+          x = float32(),
+          y = float32(),
+          z = float32()
+        )
+      ) |>
+      transmute(c = coalesce(w, x, y, z)) |>
+      compute())$schema[[1]]$type,
     float32()
   )
   # with R literal values
   expect_identical(
-    arrow_table(df) %>%
+    arrow_table(df) |>
       mutate(
         c1 = coalesce(4.4),
         c2 = coalesce(NA_real_),
@@ -471,7 +480,7 @@ test_that("coalesce()", {
         c4 = coalesce(w, x, y, 5.5),
         c5 = coalesce(w, x, y, NA_real_),
         c6 = coalesce(w, x, y, NaN)
-      ) %>%
+      ) |>
       collect(),
     mutate(
       df,
@@ -496,14 +505,14 @@ test_that("external objects are found when they're not in the global environment
   dat <- arrow_table(x = c("a", "b"))
   pattern <- "a"
   expect_identical(
-    dat %>%
-      mutate(x2 = case_when(x == pattern ~ "foo")) %>%
+    dat |>
+      mutate(x2 = case_when(x == pattern ~ "foo")) |>
       collect(),
     tibble(x = c("a", "b"), x2 = c("foo", NA))
   )
   expect_identical(
-    dat %>%
-      mutate(x2 = if_else(x == pattern, "foo", NA_character_)) %>%
+    dat |>
+      mutate(x2 = if_else(x == pattern, "foo", NA_character_)) |>
       collect(),
     tibble(x = c("a", "b"), x2 = c("foo", NA))
   )
